@@ -335,7 +335,7 @@ public class ProjectsCaller {
 		LOG.info("performStep called for profileID: {}, projectID: {}. Optional message exists?: {}", profileID, projectID, optionalMessage!=null);
 		Projects<Project> client = (Projects<Project>) getClient(profileID);
 		StepExecutionRequest request = new StepExecutionRequest(stepID, optionalMessage, options);
-		Project project = client.performStep(projectID, optionalMessage, request);
+		Project project = client.performStep(projectID, request);
 
 		LOG.info("performStep returning project ID: " + project.getId());
 		return project;
